Crate raw_stdpipes

Crate raw_stdpipes 

Raw handles to the standard terminal pipes.

Functions

raw_stderr
Raw handle to the standard error in File form,all bytes written are displayed in the terminal.
raw_stdin
Raw handle to the standard input in File form,all bytes readed come from input in the terminal.
raw_stdout
Raw handle to the standard output in File form,all bytes written are displayed in the terminal.